==> qmmp-1.3.4-1.src.tar.gz: qmmp-1.3.4/src/plugins/General/notifier/translations/notifier_plugin_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru">
<context>
    <name>NotifierFactory</name>
    <message>
        <location filename="../notifierfactory.cpp" line="29"/>
        <source>Notifier Plugin</source>
        <translation>Модуль уведомлений</translation>
    </message>
    <message>
        <location filename="../notifierfactory.cpp" line="49"/>
        <source>About Notifier Plugin</source>
        <translation>О модуле уведомлений</translation>
    </message>
    <message>
        <location filename="../notifierfactory.cpp" line="50"/>
        <source>Qmmp Notifier Plugin</source>
        <translation>Модуль уведомлений для Qmmp</translation>
    </message>
    <message>
        <location filename="../notifierfactory.cpp" line="51"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Разработчик: Илья Котов &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
<context>
    <name>PopupWidget</name>
    <message>
        <location filename="../popupwidget.cpp" line="116"/>
        <source>Volume:</source>
        <translation>Громкость:</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>Notifier Plugin Settings</source>
        <translation>Настройки модуля уведомлений</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="35"/>
        <source>Desktop Notification</source>
        <translation>Сообщение на рабочем столе</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="51"/>
        <source>Font:</source>
        <translation>Шрифт:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="71"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="78"/>
        <location filename="../settingsdialog.ui" line="279"/>
        <source>0</source>
        <translation>0</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="85"/>
        <source>Transparency:</source>
        <translation>Прозрачность:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="229"/>
        <source>Position</source>
        <translation>Положение</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="251"/>
        <source>Edit template</source>
        <translation>Редактировать шаблон</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="299"/>
        <source>Cover size:</source>
        <translation>Размер обложки:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="325"/>
        <source>Volume change notification</source>
        <translation>Уведомление о смене громкости</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="332"/>
        <source>Delay (ms):</source>
        <translation>Задежка (мс):</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="361"/>
        <source>Playback resume notification</source>
        <translation>Уведомлять о продолжении воспроизведения</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="368"/>
        <source>Song change notification</source>
        <translation>Уведомление о смене песни</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="375"/>
        <source>Disable notifications when another application is in the Full Screen Mode</source>
        <translation>Отключает уведомление, если выполняется программа в полноэкранном режиме</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="378"/>
        <source>Disable for full screen windows</source>
        <translation>Отключить для полноэкранных окон</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="388"/>
        <source>Psi Notification</source>
        <translation>Уведомление Psi</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="400"/>
        <source>Enable Psi notification</source>
        <translation>Включить уведомление Psi</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="109"/>
        <source>Notification Template</source>
        <translation>Шаблон уведомления</translation>
    </message>
</context>
</TS>

==> qmmp-2.2.4-1.src.tar.gz: qmmp-2.2.4/src/plugins/General/notifier/translations/notifier_plugin_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru">
<context>
    <name>NotifierFactory</name>
    <message>
        <location filename="../notifierfactory.cpp" line="29"/>
        <source>Notifier Plugin</source>
        <translation>Модуль уведомлений</translation>
    </message>
    <message>
        <location filename="../notifierfactory.cpp" line="49"/>
        <source>About Notifier Plugin</source>
        <translation>О модуле уведомлений</translation>
    </message>
    <message>
        <location filename="../notifierfactory.cpp" line="50"/>
        <source>Qmmp Notifier Plugin</source>
        <translation>Модуль уведомлений для Qmmp</translation>
    </message>
    <message>
        <location filename="../notifierfactory.cpp" line="51"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Разработчик: Илья Котов &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
<context>
    <name>NotifierSettingsDialog</name>
    <message>
        <location filename="../notifiersettingsdialog.ui" line="14"/>
        <source>Notifier Plugin Settings</source>
        <translation>Настройки модуля уведомлений</translation>
    </message>
    <message>
        <location filename="../notifiersettingsdialog.ui" line="35"/>
        <source>Desktop Notification</source>
        <translation>Сообщение на рабочем столе</translation>
    </message>
    <message>
        <location filename="../notifiersettingsdialog.ui" line="51"/>
        <source>Font:</source>
        <translation>Шрифт:</translation>
    </message>
    <message>
        <location filename="../notifiersettingsdialog.ui" line="71"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../notifiersettingsdialog.ui" line="78"/>
        <location filename="../notifiersettingsdialog.ui" line="279"/>
        <source>0</source>
        <translation>0</translation>
    </message>
    <message>
        <location filename="../notifiersettingsdialog.ui" line="85"/>
        <source>Transparency:</source>
        <translation>Прозрачность:</translation>
    </message>
    <message>
        <location filename="../notifiersettingsdialog.ui" line="229"/>
        <source>Position</source>
        <translation>Позиция</translation>
    </message>
    <message>
        <location filename="../notifiersettingsdialog.ui" line="251"/>
        <source>Edit template</source>
        <translation>Редактировать шаблон</translation>
    </message>
    <message>
        <location filename="../notifiersettingsdialog.ui" line="299"/>
        <source>Cover size:</source>
        <translation>Размер обложки:</translation>
    </message>
    <message>
        <location filename="../notifiersettingsdialog.ui" line="325"/>
        <source>Volume change notification</source>
        <translation>Уведомление о смене громкости</translation>
    </message>
    <message>
        <location filename="../notifiersettingsdialog.ui" line="332"/>
        <source>Delay (ms):</source>
        <translation>Задежка (мс):</translation>
    </message>
    <message>
        <location filename="../notifiersettingsdialog.ui" line="361"/>
        <source>Playback resume notification</source>
        <translation>Уведомлять о продолжении воспроизведения</translation>
    </message>
    <message>
        <location filename="../notifiersettingsdialog.ui" line="368"/>
        <source>Song change notification</source>
        <translation>Уведомление о смене песни</translation>
    </message>
    <message>
        <location filename="../notifiersettingsdialog.ui" line="375"/>
        <source>Disable notifications when another application is in the Full Screen Mode</source>
        <translation>Отключает уведомление, если выполняется программа в полноэкранном режиме</translation>
    </message>
    <message>
        <location filename="../notifiersettingsdialog.ui" line="378"/>
        <source>Disable for full screen windows</source>
        <translation>Отключить для полноэкранных окон</translation>
    </message>
    <message>
        <location filename="../notifiersettingsdialog.ui" line="388"/>
        <source>Psi Notification</source>
        <translation>Уведомление Psi</translation>
    </message>
    <message>
        <location filename="../notifiersettingsdialog.ui" line="400"/>
        <source>Enable Psi notification</source>
        <translation>Включить уведомление Psi</translation>
    </message>
    <message>
        <location filename="../notifiersettingsdialog.cpp" line="115"/>
        <source>Notification Template</source>
        <translation>Шаблон уведомления</translation>
    </message>
</context>
<context>
    <name>PopupWidget</name>
    <message>
        <location filename="../popupwidget.cpp" line="115"/>
        <source>Volume:</source>
        <translation>Громкость:</translation>
    </message>
</context>
</TS>
